archive

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExtractDownloadArchive

func ExtractDownloadArchive(source io.Reader, rawLocalTarget string) error

ExtractDownloadArchive extracts one downloaded tar archive onto the local filesystem.

Types

type UploadArchive

type UploadArchive struct {
	BoxAbsPath string
	File       *os.File
}

UploadArchive describes one prepared local tar archive and the target box path.

func BuildUploadArchive

func BuildUploadArchive(localSource string, rawBoxTarget string) (UploadArchive, error)

BuildUploadArchive packages one local file or directory into a tar stream.

Jump to