Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type UploadArchive ¶
UploadArchive describes one prepared local tar archive and the target box path.
func BuildUploadArchive ¶
func BuildUploadArchive(localSource string, rawBoxTarget string) (UploadArchive, error)
BuildUploadArchive packages one local file or directory into a tar stream.
Click to show internal directories.
Click to hide internal directories.